@@ -124,7 +124,7 @@ BlackBoostModel <- function(
     },
 
     varimp = function(object, ...) {
-      structure(mboost::varimp(object), class = "numeric")
+      structure(mboost::varimp(object), class = "numeric", metric = "risk")
     }
 
   )
