@@ -117,7 +117,7 @@ GAMBoostModel <- function(
     },
 
     varimp = function(object, ...) {
-      structure(mboost::varimp(object), class = "numeric")
+      structure(mboost::varimp(object), class = "numeric", metric = "risk")
     }
 
   )
