@@ -100,8 +100,10 @@ MLModelFunction(StackedModel) <- NULL
 .predict.StackedModel <- function(object, model_fit, newdata, ...) {
   pred <- 0
   for (i in seq_along(model_fit$base_fits)) {
-    base_pred <- predict(model_fit$base_fits[[i]], newdata = newdata,
-                         times = model_fit$times, type = "default")
+    base_pred <- predict(
+      model_fit$base_fits[[i]], newdata = newdata, times = model_fit$times,
+      type = "raw"
+    )
     pred <- pred + model_fit$weights[i] * base_pred
   }
   pred
