@@ -97,7 +97,7 @@ MLModelFunction(SuperModel) <- NULL
 
 .predict.SuperModel <- function(object, model_fit, newdata, times, ...) {
   predictors <- map(function(fit) {
-    predict(fit, newdata = newdata, times = model_fit$times, type = "default")
+    predict(fit, newdata = newdata, times = model_fit$times, type = "raw")
   }, model_fit$base_fits)
 
   df <- if (model_fit$all_vars) {
@@ -107,7 +107,7 @@ MLModelFunction(SuperModel) <- NULL
     super_df(NA, predictors)
   }
 
-  predict(model_fit$super_fit, newdata = df, times = times, type = "default")
+  predict(model_fit$super_fit, newdata = df, times = times, type = "raw")
 }
 
 
