@@ -107,8 +107,9 @@ set_monitor.MLControl <- function(
   object, progress = TRUE, verbose = FALSE, ...
 ) {
   verbose <- check_logical(verbose)
-  object@monitor <- set_monitor(object@monitor, progress = progress,
-                                verbose = verbose)
+  object@monitor <- set_monitor(
+    object@monitor, progress = progress, verbose = verbose
+  )
   object
 }
 
@@ -118,12 +119,18 @@ set_monitor.MLControl <- function(
 set_monitor.MLOptimization <- function(
   object, progress = FALSE, verbose = FALSE, ...
 ) {
-  object@monitor <- set_monitor(object@monitor, progress = progress,
-                                verbose = verbose)
+  object@monitor <- set_monitor(
+    object@monitor, progress = progress, verbose = verbose
+  )
   object
 }
 
 
+set_monitor.SplitControl <- function(object, ...) {
+  set_monitor.MLControl(object, ...)
+}
+
+
 set_monitor.TrainingParams <- function(object, which = "all", ...) {
   if (which == "all") which <- c("control", "optim")
   for (name in which) {
