@@ -91,8 +91,11 @@ dependence <- function(
   predict_stats <- function(data) {
     stats_list <- map(
       function(x) stats(if (na.rm) na.omit(x) else x),
-      as.data.frame(predict(object, newdata = data, type = "default",
-                            distr = distr, method = method))
+      as.data.frame(
+        predict(
+          object, newdata = data, type = "raw", distr = distr, method = method
+        )
+      )
     )
     x <- do.call(cbind, stats_list)
     if (is.null(rownames(x))) rownames(x) <- make_unique(rep("stat", nrow(x)))
