@@ -3,21 +3,31 @@ VariableImportance <- function(object, ...) {
 }
 
 
-VariableImportance.default <- function(object, scale = TRUE, ...) {
+VariableImportance.data.frame <- function(
+  object, method = character(), metric = character(), scale = TRUE,
+  sort = "decreasing", ...
+) {
   stopifnot(nrow(object) == 0 || is.character(rownames(object)))
 
   object <- object[rownames(object) != "(Intercept)", , drop = FALSE]
-  if (scale) scale <- max(object, 0) / 100
-  if (scale > 0) {
-    object <- object / scale
-    sort_vals <- rowSums(object)
+  scale <- rep_len(scale, ncol(object))
+  if (any(scale)) {
+    scale_num <- max(object[scale], 0) / 100
+    object[scale] <- object[scale] / scale_num
+    if (!all(scale)) scale_num <- ifelse(scale, scale_num, NA_real_)
+    sort_vals <- if (scale[1]) rowSums(object[scale]) else object[[1]]
   } else {
-    scale <- 1
-    sort_vals <- object[, 1]
+    scale_num <- NA_real_
+    sort_vals <- object[[1]]
+  }
+  if (sort != "asis") {
+    sort_order <- order(sort_vals, decreasing = sort == "decreasing")
+    object <- object[sort_order, , drop = FALSE]
   }
-  object <- object[order(sort_vals, decreasing = TRUE), , drop = FALSE]
 
-  new("VariableImportance", object, scale = scale)
+  new("VariableImportance",
+    object, method = method, metric = as.character(metric), scale = scale_num
+  )
 }
 
 
@@ -31,9 +41,36 @@ VariableImportance.numeric <- function(object, ...) {
 }
 
 
+VariableImportance.NULL <- function(object, ...) {
+  throw(Error("No variables for which to compute importance."))
+}
+
+
+update.VariableImportance <- function(object, ...) {
+  if (!.hasSlot(object, "method")) {
+    names_split <- strsplit(names(object), ".", fixed = TRUE)
+    if (names_split[[1]][1] == "Permute") {
+      method <- "permute"
+      metric <- names_split[[1]][3]
+      stats <- sapply(names_split, function(x) x[2])
+      stats[nchar(stats) == 0] <- "stat"
+      names(object) <- make_unique(stats, sep = "")
+    } else{
+      method <- "model"
+      metric <- character()
+    }
+    slot(object, "method", check = FALSE) <- method
+    slot(object, "metric", check = FALSE) <- metric
+  }
+  object
+}
+
+
 #' Variable Importance
 #'
-#' Calculate measures of the relative importance of predictors in a model.
+#' Calculate measures of relative importance for model predictor variables.
+#'
+#' @rdname varimp
 #'
 #' @param object model \link{fit} result.
 #' @param method character string specifying the calculation of variable
@@ -43,8 +80,11 @@ VariableImportance.numeric <- function(object, ...) {
 #'   values (below).  Permutation-based variable importance is defined as the
 #'   relative change in model predictive performances between datasets with and
 #'   without permuted values for the associated variable (Fisher et al. 2019).
-#' @param scale logical indicating whether importance values should be scaled to
-#'   a maximum of 100.
+#' @param scale logical value or vector indicating whether importance values are
+#'   scaled to a maximum of 100.
+#' @param sort character string specifying the sort order of importance values
+#'   to be \code{"decreasing"}, \code{"increasing"}, or as predictors appear in
+#'   the model formula (\code{"asis"}).
 #' @param ... arguments passed to model-specific or permutation-based variable
 #'   importance functions.  These include the following arguments and default
 #'   values for \code{method = "permute"}.
@@ -81,6 +121,29 @@ VariableImportance.numeric <- function(object, ...) {
 #'       iterative progress during computation.}
 #'   }
 #'
+#' @details
+#' The \code{varimp} function supports calculation of variable importance with
+#' the permutation-based method of Fisher et al. (2019) or with model-based
+#' methods where defined.  Permutation-based importance is the default and has
+#' the advantages of being available for any model, any performance metric
+#' defined for the associated response variable type, and any predictor variable
+#' in the original training dataset.  Conversely, model-specific importance is
+#' not defined for some models and will fall back to the permutation method in
+#' such cases; is generally limited to metrics implemented in the source
+#' packages of models; and may be computed on derived, rather than original,
+#' predictor variables.  These disadvantages can make comparisons of
+#' model-specific importance across different classes of models infeasible.  A
+#' downside of the permutation-based approach is increased computation time.  To
+#' counter this, the permutation algorithm can be run in parallel simply by
+#' loading a parallel backend for the \pkg{foreach} package \code{\%dopar\%}
+#' function, such as \pkg{doParallel} or \pkg{doSNOW}.
+#'
+#' Permutation variable importance is interpreted as the contribution of a
+#' predictor variable to the predictive performance of a model as measured by
+#' the performance metric used in the calculation.  Importance of a predictor is
+#' conditional on and, with the default scaling, relative to the values of all
+#' other predictors in the analysis.
+#'
 #' @return \code{VariableImportance} class object.
 #'
 #' @references
@@ -103,13 +166,19 @@ VariableImportance.numeric <- function(object, ...) {
 #' plot(vi)
 #' }
 #'
-varimp <- function(object, method = c("permute", "model"), scale = TRUE, ...) {
+varimp <- function(
+  object, method = c("permute", "model"), scale = TRUE,
+  sort = c("decreasing", "increasing", "asis"), ...
+) {
   stopifnot(is(object, "MLModelFit"))
   object <- update(object)
   model <- as.MLModel(object)
   throw(check_packages(model@packages))
 
-  switch(match.arg(method),
+  method <- match.arg(method)
+  sort <- match.arg(sort)
+
+  switch(method,
     "model" = {
       .MachineShop <- attr(object, ".MachineShop")
       vi <- model@varimp(unMLModelFit(object), .MachineShop = .MachineShop, ...)
@@ -118,6 +187,7 @@ varimp <- function(object, method = c("permute", "model"), scale = TRUE, ...) {
           "Model-specific variable importance is not available; ",
           "computing permutation-based importance instead."
         ))
+        method <- "permute"
         vi <- varimp_permute(object)
       }
     },
@@ -126,7 +196,12 @@ varimp <- function(object, method = c("permute", "model"), scale = TRUE, ...) {
       vi <- do.call(varimp_permute, args, envir = parent.frame())
     }
   )
-  VariableImportance(vi, scale = scale)
+  metric <- attr(vi, "metric")
+  attr(vi, "metric") <- NULL
+  
+  VariableImportance(
+    vi, method = method, metric = metric, scale = scale, sort = sort
+  )
 }
 
 
@@ -169,9 +244,9 @@ varimp_permute <- function(
   throw(check_assignment(stats))
 
   varimp <- function(x, baseline, maximize = FALSE) {
-    args <- if (maximize) list(baseline, x) else list(x, baseline)
+    compare_args <- if (maximize) list(baseline, x) else list(x, baseline)
     do.call(rbind,
-      apply(do.call(compare, args), 2, function(col) {
+      apply(do.call(compare, compare_args), 2, function(col) {
         stats(if (na.rm) na.omit(col) else col)
       }, simplify = FALSE)
     )
@@ -189,15 +264,20 @@ varimp_permute <- function(
     function() NULL
   }
 
-  num_workers <- getDoParWorkers()
   work <- pred_names
-  length(work) <- num_workers * ceiling(length(work) / num_workers)
-  work_pred_names <- map(na.omit, split(work, seq_len(num_workers)))
+  num_workers <- getDoParWorkers()
+  num_tasks <- ceiling(length(work) / num_workers)
+  length(work) <- num_workers * num_tasks
+  jobs <- map(na.omit, split(work, rep(1:num_workers, each = num_tasks)))
   seeds <- rand_int(samples)
 
   foreach(
-    pred_names = work_pred_names[lengths(work_pred_names) > 0],
-    .combine = rbind,
+    pred_names = jobs[lengths(jobs) > 0],
+    .multicombine = TRUE,
+    .combine = function(...) {
+      structure(rbind(...), metric = attr(..1, "metric"))
+    },
+    .inorder = TRUE,
     .export = c("as.MLMetric", "get_perf_metrics", "map", "permute_int"),
     .packages = "MachineShop"
   ) %dopar% {
@@ -211,7 +291,7 @@ varimp_permute <- function(
       base_perf[s] <- if (s == 1 || subset) {
         newdata <- if (subset) data[inds$i, ] else data
         obs <- response(object, newdata)
-        pred <- predict(object, newdata, times = times, type = "default")
+        pred <- predict(object, newdata, times = times, type = "raw")
         if (is.null(metric)) {
           metric <- as.MLMetric(get_perf_metrics(obs, pred)[[1]])
         }
@@ -222,15 +302,13 @@ varimp_permute <- function(
       for (name in pred_names) {
         x <- newdata[[name]]
         newdata[[name]] <- data[[name]][inds$j]
-        pred <- predict(object, newdata, times = times, type = "default")
+        pred <- predict(object, newdata, times = times, type = "raw")
         perf[s, name] <- metric(obs, pred)[1]
         newdata[[name]] <- x
         progress()
       }
     }
-    res <- varimp(perf, base_perf, metric@maximize)
-    colnames(res) <- paste0("Permute.", colnames(res), ".", metric@name)
-    res
+    structure(varimp(perf, base_perf, metric@maximize), metric = metric@name)
   }
 }
 
@@ -240,32 +318,30 @@ varimp_pval <- function(object, ...) {
 }
 
 
-varimp_pval.default <- function(object, ...) {
-  varimp_pval(coef(object), diag(vcov(object)), ...)
-}
-
-
-varimp_pval.glm <- function(object, base = exp(1), ...) {
-  anova <- drop1(object, test = "Chisq")
-  -log(anova[-1, "Pr(>Chi)", drop = FALSE], base = base)
-}
-
-
-varimp_pval.lm <- function(object, base = exp(1), ...) {
-  anova <- drop1(object, test = "F")
-  -log(anova[-1, "Pr(>F)", drop = FALSE], base = base)
+varimp_pval.default <- function(object, test = "Chisq", base = exp(1), ...) {
+  res <- rev(drop1(object, test = test))[-1, 1, drop = FALSE]
+  structure(
+    -log(res[[1]], base = base),
+    names = rownames(res),
+    metric = paste0(
+      "-log", if (base != exp(1)) paste0("(base = ", as_string(base), ")"),
+      " ", names(res)
+    )
+  )
 }
 
 
 varimp_pval.mlm <- function(object, ...) {
   check <- check_equal_weights(object$weights)
   if (is(check, "warning")) {
-    throw(LocalWarning("Model-specific variable importance not defined for ",
-                       class1(object), " with case weights."))
+    throw(LocalWarning(
+      "Model-specific variable importance not defined for ", class1(object),
+      " with case weights."
+    ))
     NULL
   } else {
     object$weights <- NULL
-    varimp_pval.default(object, ...)
+    varimp_pval(coef(object), diag(vcov(object)), ...)
   }
 }
 
@@ -276,5 +352,11 @@ varimp_pval.multinom <- function(object, ...) {
 
 
 varimp_pval.numeric <- function(object, var, base = exp(1), ...) {
-  -log(pchisq(object^2 / var, 1, lower.tail = FALSE), base = base)
+  structure(
+    -log(pchisq(object^2 / var, 1, lower.tail = FALSE), base = base),
+    metric = paste0(
+      "-log", if (base != exp(1)) paste0("(base = ", as_string(base), ")"),
+      " Pr(>Chi)"
+    )
+  )
 }
